/*! \file main.c

  \brief rastertoepsidm main function

  \author
    Copyright (C) SEIKO EPSON CORPORATION 2010.

    Driver for Epson SIDM Printers

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License or
    any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <stdio.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <unistd.h>

/* #include <cups/cups.h> */

#include "common.h"
#include "rastertoepsidm.h"
#include "debug.h"


/*! \brief main
  \param  argc  number of params
  \param  argv  commandline parameters
  \return       error status
  \retval 0     completed
  \retval other error
 */
int main (int argc, char *argv[])
{
  int            fd = -1;       /* Input File descriptor */
  int            status = 0;

  /* setbuf(stderr, NULL); */

  if ((6 > argc) || (7 < argc)) {
    fprintf(stderr, "Usage: %s job-id user title copies options [file]\n", argv[0]);
    return 1;
  }

 /*
  * Open the page stream...
  */

  if (7 == argc) {
    if ((fd = open(argv[6], O_RDONLY)) == -1) {
      DEBUG_ERROR_TRACE;
      perror("ERROR: Unable to open raster file - ");
      return 1;
    }
  } else {
    fd = 0;
  }

  /* debug: open debug log file and image out file. */
  debug_open(argv[0], argv[1]);

  /* debug: function start index. */
  FUNCSTART;

  /* debug: Show ENV parameters to debug log file. */
  if (1) { debug_show_env(); }

  /* debug: Show command-line argument strings. */
  if (1) {
    int i;
    for ( i = 0; i < argc; i++ ) {
      dbgprintf("argv[%d]=\"%s\"\n", i, argv[i]);
    }
  }

  status = rastertoepsidm(fd, argv[5]);

  if (fd > 0) {
    close(fd);
  }

  /* debug: close debug log file and image out file. */
  debug_close();

  return status;
}

/* end of file */
